@@ -48,6 +48,7 @@
 
 package com.openexchange.documentconverter.client.impl;
 
+import static org.apache.commons.lang.StringUtils.isBlank;
 import static org.apache.commons.lang.StringUtils.isNotBlank;
 import java.io.File;
 import java.net.URL;
@@ -275,14 +276,22 @@ public class ClientConfig {
         }
 
         // PDFEXTRACTOR_WORKDIR
-        if (itemsToRead.contains(CONFIGITEM_PDFEXTRACTOR_WORK_DIR) &&
-            isNotBlank(curStringEntry = configService.getProperty(CONFIGITEM_PDFEXTRACTOR_WORK_DIR, emptyString))) {
+        if (itemsToRead.contains(CONFIGITEM_PDFEXTRACTOR_WORK_DIR)) {
+            curStringEntry = configService.getProperty(CONFIGITEM_PDFEXTRACTOR_WORK_DIR);
+
+            if (isBlank(curStringEntry)) {
+                curStringEntry = configService.getProperty("UPLOAD_DIRECTORY");
+
+                if (isBlank(curStringEntry)) {
+                    curStringEntry = FileUtils.getTempDirectoryPath();
+                }
+            }
 
             final File pdfExtractorWorkDir = new File(curStringEntry, PDFEXTRACTOR_EXECUTABLE_WORKDIR_NAME);
 
             FileUtils.deleteQuietly(pdfExtractorWorkDir);
 
-            if (DocumentConverterManager.mkdirs(pdfExtractorWorkDir)) {
+            if (DocumentConverterManager.validateOrMkdir(pdfExtractorWorkDir)) {
                 PDFEXTRACTOR_WORKDIR = pdfExtractorWorkDir;
             } else {
                 DocumentConverterManager.logError("DC client PDF extraction tool working directoy cannot be created or is not writable: " +
