@@ -110,10 +110,16 @@ public abstract class DocumentConverterAction implements AJAXActionService {
 
     final protected static String FORMAT_FILE = "file";
 
+    final protected static String JSON_KEY_ORIGIN = "origin";
+
     final protected static String JSON_KEY_ERRORCODE = "errorCode";
 
     final protected static String JSON_KEY_ERRORTEXT = "cause";
 
+    final protected static String JSON_KEY_INVALID_CHARS = "invalidCharacters";
+
+    final protected static String JSON_VALUE_DOUMENTCONVERTER = "DocumentConverter";
+
     /**
      * Initializes a new {@link DocumentConverterAction}.
      *
@@ -367,7 +373,13 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                                         resultFile = m_fileIdManager.setDataInputStream(resultJobId.get(), pdfResultStm);
                                         resultJobError.set(JobError.NONE);
                                     } else {
-                                        resultJobError.set(isAsync ? JobError.NONE : JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)));
+                                        JobError pdfJobError = JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
+
+                                        if (JobError.NONE == pdfJobError) {
+                                            pdfJobError = JobError.GENERAL;
+                                        }
+
+                                        resultJobError.set(isAsync ? JobError.NONE : pdfJobError);
                                     }
                                 }
                             }
@@ -404,6 +416,8 @@ public abstract class DocumentConverterAction implements AJAXActionService {
             final JSONObject jsonResult = (null != jsonObject) ? jsonObject : new JSONObject();
 
             try {
+                jsonResult.put(JSON_KEY_ORIGIN, JSON_VALUE_DOUMENTCONVERTER);
+
                 if ((null != jobError) && (jobError != JobError.NONE) && !jsonResult.has(JSON_KEY_ERRORTEXT)) {
                     jsonResult.put(JSON_KEY_ERRORTEXT,  jobError.errorText());
                 }
