@@ -53,9 +53,11 @@ import java.io.File;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.lang.StringUtils;
+import org.json.JSONArray;
 import org.json.JSONObject;
 import com.openexchange.ajax.container.FileHolder;
 import com.openexchange.ajax.fileholder.IFileHolder;
@@ -127,7 +129,7 @@ public class GetDocumentAction extends DocumentConverterAction {
             "pdf".equalsIgnoreCase(request.getParameter("documentformat")) &&
             !"pdf".equals(fileExtension) && !"application/pdf".equalsIgnoreCase(mimeType);
 
-        if ((!convertToPDF || (null == (resultFile = getPDFFile(request, session, isAsync, documentDecrypted, jobId, jobError)))) && !isAsync) {
+        if ((!convertToPDF || ((null == (resultFile = getPDFFile(request, session, isAsync, documentDecrypted, jobId, jobError))) && (JobError.NONE == jobError.get()))) && !isAsync) {
             final IDocumentConverter docConverter = m_services.getService(IDocumentConverter.class);
             final String encTest = request.getParameter("enctest");
 
@@ -236,9 +238,17 @@ public class GetDocumentAction extends DocumentConverterAction {
                 DocumentConverterManager.logError("DC client Ajax handler was called with an invalid 'saveas_filename' parameter for save request: " + sessionId);
 
                 final JSONObject jsonError = new JSONObject();
+                final List<String> invalidCharsList = new ArrayList<>();
+
+                for (final char curInvalidChar : INVALID_FILENAME_CHARS) {
+                    if (StringUtils.contains(saveAsFileName, curInvalidChar)) {
+                        invalidCharsList.add(String.valueOf(curInvalidChar));
+                    }
+                }
 
                 jsonError.put(JSON_KEY_ERRORCODE, ERRORCODE_BAD_REQUEST);
                 jsonError.put(JSON_KEY_ERRORTEXT, ERRORTEXT_INVALID_FILENAME);
+                jsonError.put(JSON_KEY_INVALID_CHARS, new JSONArray(invalidCharsList));
 
                 ret = jsonError;
             } else {
